@@ -16,9 +16,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(ADVANCEDPAGEWIDGET__H)
+#if !defined(ADVANCEDPAGEWIDGET_H)
 
-#define ADVANCEDPAGEWIDGET__H
+#define ADVANCEDPAGEWIDGET_H
 
 #include "ui_configurepageadvanced.h"
 
