@@ -51,9 +51,9 @@ void GeneralPageWidget::setupDialog()
         if (fs->supportCreate() != FileSystem::cmdSupportNone && fs->type() != FileSystem::Extended && fs->type() != FileSystem::Luks)
             fsNames.append(fs->name());
 
-    qSort(fsNames.begin(), fsNames.end(), caseInsensitiveLessThan);
+    std::sort(fsNames.begin(), fsNames.end(), caseInsensitiveLessThan);
 
-    for (const auto &fsName : fsNames)
+    for (const auto &fsName : qAsConst(fsNames))
         comboDefaultFileSystem().addItem(createFileSystemColor(FileSystem::typeForName(fsName), 8), fsName);
 
     setDefaultFileSystem(GuiHelpers::defaultFileSystem());
