@@ -40,7 +40,7 @@ CreatePartitionTableDialog::CreatePartitionTableDialog(QWidget* parent, const De
     setWindowTitle(xi18nc("@title:window", "Create a New Partition Table on <filename>%1</filename>", device().deviceNode()));
     dialogButtonBox = new QDialogButtonBox;
     createButton = dialogButtonBox->addButton(QDialogButtonBox::Ok);
-    createButton->setText(i18n("Create &New Partition Table"));
+    createButton->setText(xi18nc("@action:button", "Create &New Partition Table"));
     cancelButton = dialogButtonBox->addButton(QDialogButtonBox::Cancel);
     mainLayout->addWidget(dialogButtonBox);
 
@@ -62,13 +62,13 @@ PartitionTable::TableType CreatePartitionTableDialog::type() const
 
 void CreatePartitionTableDialog::onMSDOSToggled(bool on)
 {
-    if (on && device().totalSectors() > 0xffffffff) {
+    if (on && device().totalLogical() > 0xffffffff) {
         if (KMessageBox::warningContinueCancel(this,
                                                xi18nc("@info",
                                                        "<para>Do you really want to create an MS-Dos partition table on <filename>%1</filename>?</para>"
                                                        "<para>This device has more than 2^32 sectors. That is the most the MS-Dos partition table type supports, so you will not be able to use the whole device.</para>", device().deviceNode()),
-                                               i18nc("@title:window", "Really Create MS-Dos Partition Table Type?"),
-                                               KGuiItem(i18nc("@action:button", "Create MS-Dos Type"), QStringLiteral("arrow-right")),
+                                               xi18nc("@title:window", "Really Create MS-Dos Partition Table Type?"),
+                                               KGuiItem(xi18nc("@action:button", "Create MS-Dos Type"), QStringLiteral("arrow-right")),
                                                KStandardGuiItem::cancel(), QStringLiteral("reallyCreateMSDOSOnLargeDevice")) == KMessageBox::Cancel) {
             widget().radioGPT().setChecked(true);
         }
