@@ -16,9 +16,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(CREATEPARTITIONTABLEDIALOG__H)
+#if !defined(CREATEPARTITIONTABLEDIALOG_H)
 
-#define CREATEPARTITIONTABLEDIALOG__H
+#define CREATEPARTITIONTABLEDIALOG_H
 
 #include "gui/createpartitiontablewidget.h"
 
