@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(CREATEVOLUMEGROUPDIALOG__H)
+#if !defined(CREATEVOLUMEGROUPDIALOG_H)
 
-#define CREATEVOLUMEGROUPDIALOG__H
+#define CREATEVOLUMEGROUPDIALOG_H
 
 #include <core/device.h>
 #include <fs/lvm2_pv.h>
@@ -31,7 +31,7 @@ class CreateVolumeGroupDialog : public VolumeGroupDialog
     Q_DISABLE_COPY(CreateVolumeGroupDialog)
 
 public:
-    CreateVolumeGroupDialog(QWidget* parent, QString& vgName, std::vector<const Partition*>& pvList, qint32& peSize, QList<Device*> devices);
+    CreateVolumeGroupDialog(QWidget* parent, QString& vgName, QVector<const Partition*>& pvList, qint32& peSize, QList<Device*> devices);
 
 protected:
     void accept() override;
