@@ -22,21 +22,21 @@
 #include "gui/smartdialog.h"
 
 #include <core/device.h>
+#include <core/diskdevice.h>
 #include <core/partitiontable.h>
 #include <core/smartstatus.h>
 
 #include <util/capacity.h>
 #include <util/helpers.h>
 
-#include <KLocalizedString>
-#include <KSharedConfig>
 #include <KConfigGroup>
 #include <KIconLoader>
+#include <KLocalizedString>
+#include <KSharedConfig>
 
 #include <QDialogButtonBox>
 #include <QPointer>
 #include <QPushButton>
-#include <QTreeWidgetItem>
 
 /** Creates a new DevicePropsDialog
     @param parent pointer to the parent widget
@@ -84,7 +84,7 @@ void DevicePropsDialog::setupDialog()
 
     if (device().partitionTable() != nullptr) {
         type = (device().partitionTable()->isReadOnly())
-               ? i18nc("@label device", "%1 (read only)", device().partitionTable()->typeName())
+               ? xi18nc("@label device", "%1 (read only)", device().partitionTable()->typeName())
                : device().partitionTable()->typeName();
         maxPrimaries = QStringLiteral("%1/%2").arg(device().partitionTable()->numPrimaries()).arg(device().partitionTable()->maxPrimaries());
 
@@ -102,31 +102,42 @@ void DevicePropsDialog::setupDialog()
         dialogWidget().hideTypeRadioButtons();
     }
 
-    dialogWidget().capacity().setText(Capacity::formatByteSize(device().capacity()));
-
-
-    const QString cyls = QLocale().toString((device().cylinders()));
-    const QString heads = QLocale().toString((device().heads()));
-    const QString sectors = QLocale().toString((device().sectorsPerTrack()));
-    dialogWidget().chs().setText(QStringLiteral("%1/%2/%3").arg(cyls).arg(heads).arg(sectors));
-
-    dialogWidget().cylinderSize().setText(i18ncp("@label", "1 Sector", "%1 Sectors", device().cylinderSize()));
-    dialogWidget().primariesMax().setText(maxPrimaries);
-    dialogWidget().logicalSectorSize().setText(Capacity::formatByteSize(device().logicalSectorSize()));
-    dialogWidget().physicalSectorSize().setText(Capacity::formatByteSize(device().physicalSectorSize()));
-    dialogWidget().totalSectors().setText(QLocale().toString((device().totalSectors())));
     dialogWidget().type().setText(type);
+    dialogWidget().capacity().setText(Capacity::formatByteSize(device().capacity()));
+    dialogWidget().totalSectors().setText(QLocale().toString(device().totalLogical()));
 
-    if (device().smartStatus().isValid()) {
-        if (device().smartStatus().status()) {
-            dialogWidget().smartStatusText().setText(i18nc("@label SMART disk status", "good"));
-            dialogWidget().smartStatusIcon().setPixmap(QIcon::fromTheme(QStringLiteral("dialog-ok")).pixmap(IconSize(KIconLoader::Small)));
+    if (device().type() == Device::Disk_Device) {
+
+        const DiskDevice& disk = dynamic_cast<const DiskDevice&>(device());
+        const QString cyls = QLocale().toString((disk.cylinders()));
+        const QString heads = QLocale().toString((disk.heads()));
+        const QString sectors = QLocale().toString((disk.sectorsPerTrack()));
+        dialogWidget().chs().setText(QStringLiteral("%1/%2/%3").arg(cyls).arg(heads).arg(sectors));
+
+        dialogWidget().cylinderSize().setText(i18ncp("@label", "1 Sector", "%1 Sectors", disk.cylinderSize()));
+        dialogWidget().primariesMax().setText(maxPrimaries);
+        dialogWidget().logicalSectorSize().setText(Capacity::formatByteSize(disk.logicalSectorSize()));
+        dialogWidget().physicalSectorSize().setText(Capacity::formatByteSize(disk.physicalSectorSize()));
+        if (device().smartStatus().isValid()) {
+            if (device().smartStatus().status()) {
+                dialogWidget().smartStatusText().setText(xi18nc("@label SMART disk status", "good"));
+                dialogWidget().smartStatusIcon().setPixmap(QIcon::fromTheme(QStringLiteral("dialog-ok")).pixmap(IconSize(KIconLoader::Small)));
+            } else {
+                dialogWidget().smartStatusText().setText(xi18nc("@label SMART disk status", "BAD"));
+                dialogWidget().smartStatusIcon().setPixmap(QIcon::fromTheme(QStringLiteral("dialog-warning")).pixmap(IconSize(KIconLoader::Small)));
+            }
         } else {
-            dialogWidget().smartStatusText().setText(i18nc("@label SMART disk status", "BAD"));
-            dialogWidget().smartStatusIcon().setPixmap(QIcon::fromTheme(QStringLiteral("dialog-warning")).pixmap(IconSize(KIconLoader::Small)));
+            dialogWidget().smartStatusText().setText(xi18nc("@label", "(unknown)"));
+            dialogWidget().smartStatusIcon().setVisible(false);
+            dialogWidget().buttonSmartMore().setVisible(false);
         }
     } else {
-        dialogWidget().smartStatusText().setText(i18nc("@label", "(unknown)"));
+        if (device().type() == Device::LVM_Device)
+            dialogWidget().type().setText(xi18nc("@label device", "LVM Volume Group"));
+        else
+            dialogWidget().type().setText(xi18nc("@label device", "Volume Manager Device"));
+        //TODO: add Volume Manger Device info
+        dialogWidget().smartStatusText().setVisible(false);
         dialogWidget().smartStatusIcon().setVisible(false);
         dialogWidget().buttonSmartMore().setVisible(false);
     }
