@@ -65,15 +65,20 @@ void EditMountPointDialog::accept()
 {
     if (KMessageBox::warningContinueCancel(this,
                                            xi18nc("@info", "<para>Are you sure you want to save the changes you made to the system table file <filename>/etc/fstab</filename>?</para>"
-                                                   "<para><warning>This will overwrite the existing file on your hard drive now. This <strong>can not be undone</strong>.</warning></para>"),
+                                                   "<para><warning>This will overwrite the existing file on your hard drive now. This <emphasis strong='1'>can not be undone</emphasis>.</warning></para>"),
                                            xi18nc("@title:window", "Really save changes?"),
                                            KGuiItem(xi18nc("@action:button", "Save changes"), QStringLiteral("arrow-right")),
                                            KStandardGuiItem::cancel(),
                                            QStringLiteral("reallyWriteMountPoints")) == KMessageBox::Cancel)
         return;
 
-    if (widget().acceptChanges() && widget().writeMountpoints(QStringLiteral("/etc/fstab")))
+    widget().acceptChanges();
+    if (writeMountpoints(widget().fstabEntries()))
         partition().setMountPoint(widget().editPath().text());
+    else
+        KMessageBox::sorry(this,
+                   xi18nc("@info", "Could not save mount points to file <filename>/etc/fstab</filename>."),
+                   xi18nc("@title:window", "Error While Saving Mount Points"));
 
     QDialog::accept();
 }
