@@ -25,9 +25,9 @@
 #include <QDialogButtonBox>
 #include <QDialog>
 
+#include <KConfigGroup>
 #include <KIconLoader>
 #include <KLocalizedString>
-#include <KConfigGroup>
 #include <KSharedConfig>
 
 /** Creates a new FileSystemSupportDialog
@@ -40,7 +40,7 @@ FileSystemSupportDialog::FileSystemSupportDialog(QWidget* parent) :
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     setLayout(mainLayout);
     mainLayout->addWidget(&dialogWidget());
-    setWindowTitle(i18nc("@title:window", "File System Support"));
+    setWindowTitle(xi18nc("@title:window", "File System Support"));
     dialogButtonBox = new QDialogButtonBox(this);
     dialogButtonBox -> setStandardButtons(QDialogButtonBox::Ok);
     mainLayout->addWidget(dialogButtonBox);
@@ -71,7 +71,7 @@ void FileSystemSupportDialog::setupDialog()
 
     dialogWidget().tree().clear();
 
-    foreach(const FileSystem * fs, FileSystemFactory::map()) {
+    for (const auto &fs : FileSystemFactory::map()) {
         if (fs->type() == FileSystem::Unknown || fs->type() == FileSystem::Extended || fs->type() == FileSystem::Luks)
             continue;
 
