@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(INFOPANE__H)
+#if !defined(INFOPANE_H)
 
-#define INFOPANE__H
+#define INFOPANE_H
 
 #include <QWidget>
 
@@ -53,7 +53,7 @@ protected:
         Q_ASSERT(m_GridLayout);
         return *m_GridLayout;
     }
-    quint32 cols(Qt::DockWidgetArea area) const;
+    qint32 cols(Qt::DockWidgetArea area) const;
 
 private:
     QGridLayout* m_GridLayout;
