@@ -24,6 +24,7 @@
 #include "gui/applyprogressdialog.h"
 #include "gui/insertdialog.h"
 #include "gui/editmountpointdialog.h"
+#include "util/guihelpers.h"
 
 #include <core/partition.h>
 #include <core/device.h>
@@ -51,8 +52,6 @@
 #include <util/report.h>
 #include <util/helpers.h>
 
-#include "util/guihelpers.h"
-
 #include <QFileDialog>
 #include <QLocale>
 #include <QPointer>
@@ -210,7 +209,7 @@ static QTreeWidgetItem* createTreeWidgetItem(const Partition& p)
 {
     QTreeWidgetItem* item = new PartitionTreeWidgetItem(&p);
 
-    quint32 i = 0;
+    int i = 0;
     item->setText(i++, p.deviceNode());
 
     if (p.roles().has(PartitionRole::Luks) && p.fileSystem().name() != p.fileSystem().nameForType(FileSystem::Luks))
@@ -328,11 +327,11 @@ void PartitionManagerWidget::on_m_PartTableWidget_itemSelectionChanged(PartWidge
     if (p) {
         QList<QTreeWidgetItem*> findResult = treePartitions().findItems(p->deviceNode(), Qt::MatchFixedString | Qt::MatchRecursive, 0);
 
-        for (const auto &item : findResult) {
-            const PartitionTreeWidgetItem* ptwItem = dynamic_cast<PartitionTreeWidgetItem*>(item);
+        for (const auto &treeWidgetItem : findResult) {
+            const PartitionTreeWidgetItem* ptwItem = dynamic_cast<PartitionTreeWidgetItem*>(treeWidgetItem);
 
             if (ptwItem && ptwItem->partition() == p) {
-                treePartitions().setCurrentItem(item);
+                treePartitions().setCurrentItem(treeWidgetItem);
                 break;
             }
         }
