@@ -18,6 +18,7 @@
 
 #include "gui/resizedialog.h"
 #include "gui/sizedialogwidget.h"
+#include "gui/sizedetailswidget.h"
 
 #include <core/partition.h>
 #include <core/device.h>
@@ -51,6 +52,9 @@ ResizeDialog::ResizeDialog(QWidget* parent, Device& d, Partition& p, qint64 minF
     dialogWidget().hideRole();
     dialogWidget().hideFileSystem();
     dialogWidget().hideLabel();
+    dialogWidget().textLVName().hide();
+    dialogWidget().lvName().hide();
+
 
     setupDialog();
     setupConstraints();
@@ -99,6 +103,12 @@ void ResizeDialog::reject()
 void ResizeDialog::setupDialog()
 {
     SizeDialogBase::setupDialog();
+    if (device().type() == Device::LVM_Device) {
+        dialogWidget().hideBeforeAndAfter();
+        detailsWidget().checkAlign().setChecked(false);
+        detailsWidget().checkAlign().setEnabled(false);
+        detailsButton->hide();
+    }
     okButton->setEnabled(false);
 }
 
@@ -125,5 +135,5 @@ bool ResizeDialog::canShrink() const
 
 bool ResizeDialog::canMove() const
 {
-    return ResizeOperation::canMove(&partition());
+    return (device().type() == Device::LVM_Device) ? false : ResizeOperation::canMove(&partition());
 }
