@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(RESIZEVOLUMEGROUPDIALOG__H)
+#if !defined(RESIZEVOLUMEGROUPDIALOG_H)
 
-#define RESIZEVOLUMEGROUPDIALOG__H
+#define RESIZEVOLUMEGROUPDIALOG_H
 
 #include <fs/lvm2_pv.h>
 
@@ -31,7 +31,7 @@ class ResizeVolumeGroupDialog : public VolumeGroupDialog
     Q_DISABLE_COPY(ResizeVolumeGroupDialog)
 
 public:
-    ResizeVolumeGroupDialog(QWidget* parent, VolumeManagerDevice *d, std::vector<const Partition*>& partList);
+    ResizeVolumeGroupDialog(QWidget* parent, VolumeManagerDevice *d, QVector<const Partition*>& partList);
 
 protected:
     void accept() override;
